function [success,p] = BoostedL1_Presolved(r,idx,instances,k)
% BOOSTEDL1_PRESOLVED   Solve a set of boosted L1 problems using presolved info
%
%    [SUCCESS,P] = BOOSTEDL1_PRESOLVED(R,IDX,INSTANCES,K)  solves the boosted
%    L1 problem on INSTANCES random problems AX=B, with A the standard 20x80
%    matrix, and X consisting of K columns. The support of X is implicitly
%    determined by the function PresolvedSupportProblem(R,IDX) and solving of
%    each basis pursuit problem is done by looking up if the given sign pattern
%    on the support of X can be recovered. Output parameters SUCCESS and P
%    respectively give the outcome of each instance and the fraction of
%    surviving faces for that support respectively.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Get matrix, support and map of surviving faces. Note that the support is
% never used, we only create the nonzero part of X.
[A,support,faces] = PresolvedSupportProblem(r,idx);

% Initialize success matrix, binary multiplicion coefficients
success  = zeros(1,k);
binary   = power(2,0:r-1);

% Initialize random number generator
randn('state',0)

for i=1:instances
   xSupport = 1*(randn(r,k)>=0); % Sign pattern of support
   xBinary  = binary * xSupport;

   for j=1:k
      if faces(xBinary(j)+1) ~= 0
         success(j:end) = success(j:end) + 1;
         break;
      end      
   end
end

% Also return actual probability
p = sum(faces) / power(2,r);
