function FigBoostedL1(exportFlag)
% FIGBOOSTEDL1   Generates recovery plot for boosted L1.
% 
%    FIGBOOSTEDL1(EXPORTFLAG)  generates the recovery plot for boosted L1 based
%    on three problems with different support size, and compares it with the
%    theoretical expected performance. When the EXPORTFLAG parameters is set
%    the plot will be exported to a PDF file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

figure(1); clf; gca; hold on;

rValues = [8,9,10];
iValues = [4,0,2];
cValues = [0.75  0      0
           0     0.75   0
           0     0      1.00];
markers = {'none','x','+'};

for i=1:length(rValues)
   instances = 1000;
   r         = rValues(i); % Row sparsity
   idx       = iValues(i); % Support number for given row sparsity
   k         = 20;         % Maximum number of observations

   [success,p] = BoostedL1_Presolved(r,idx,instances,k); 

   h1(i) = plot(100*success/instances);
   h2(i) = plot(1:k,100*(1-power(1-p,1:k)),'r--');

   set([h1(i),h2(i)],'LineWidth',2,'Color',cValues(:,i)');
   set(h1(i),'Marker',markers{i},'Markersize',7);
   set(h2(i),'Marker',markers{i},'Markersize',7);
end

hold off; box on; ylim([0,102]);
set(gca,'Fontsize',16);
xlabel('r'); ylabel('Recovery rate (%)');
legend(h1,'s = 8','s = 9','s = 10','Location','NorthWest');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(mfilepath(mfilename('fullpath')), 'FigBoostedL1.pdf');
end

