function FigBreakDownL12(r,trialsMax)
% FIGBREAKDOWNL12   Computes L11, L12 breakdown curves for a fixed 20x60 matrix
%
%    FIGBREAKDOWNL12(K,TRIALS)  computes the L11 and L12 breakdown curve for
%    the standard 20 x 60 random matrix generated with the GENERATEMATRIXA
%    function. All sparsity levels from 1 to 20 are tried on random support
%    and the average recovery rate is computed over TRIALS simulations. The
%    measurement vector B = AX has R columns.
%    Intermediate results and the script can be interrupted and restarted at
%    any time and restarted with the loss of at most 40 CVX solves. When the
%    number of trials in the stored data exceeds that given by TRIALS, the
%    number of trials in the data is used.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Load the standard 20x60 matrix A
[A,state] = GenerateMatrixA(20,60);
[m,n] = size(A);
randn('state',state); rand('state',0);

% Construct filename
filename = sprintf('%sFigBreakdownL12_r%d.mat',mfilepath(mfilename('fullpath')),r);
if exist(filename)
   load(filename);

   rand('state',randstate);
   randn('state',randnstate);
else
   trials    = 0;
   success11 = zeros(1,20);
   success12 = zeros(1,20);
end

% Run remaining trials
for i=trials+1:trialsMax
   for sparsity=1:20
      p = randperm(n);
      X0 = zeros(n,r);
      X0(p(1:sparsity),:) = randn(sparsity,r);
      B = A*X0;

      % Run L11
      [X,info] = cvx_l11(A,B);
      if norm(X(:)-X0(:),inf) < 1e-5
         success11(sparsity) = success11(sparsity) + 1;
      end


      % Run L12
      [X,info] = cvx_l12(A,B);
      if norm(X(:)-X0(:),inf) < 1e-5
         success12(sparsity) = success12(sparsity) + 1;
      end
   end

   % Increment number of completed trials
   trials = trials + 1;

   % Get random number generator status
   randstate = rand('state');
   randnstate = randn('state');

   % Save results
   save(filename,'success11','success12','randstate','randnstate','trials');

   % Display progress
   disp('==================================================================================================');
   disp('==================================================================================================');
   disp('==================================================================================================');
   disp(i);
   disp('==================================================================================================');
   disp('==================================================================================================');
   disp('==================================================================================================');
end

