function FigBreakdownL12Plot(exportFlag)
% FIGBREAKDOWNL12PLOT   Plot breakdown curves for varying # of observations
%
%    FIGBREAKDOWNL12PLOT(EXPORTFLAG)  Generates the breakdown curves for a
%    20x60 matrix A with varying numbers of observation vectors in B = AX.
%    When the EXPORTFLAG parameters is set the plot will be exported to a
%    PDF file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

% Make sure all required data are available
FigBreakdownL12(2,1000);
FigBreakdownL12(3,1000);
FigBreakdownL12(5,1000);

% Load data
prefix = mfilepath(mfilename('fullpath'));
d1 = load([prefix,'FigBreakdownL12_r2.mat']);
d2 = load([prefix,'FigBreakdownL12_r3.mat']);
d3 = load([prefix,'FigBreakdownL12_r5.mat']);

% Plot figure
figure(1); clf; gca; hold on;

h1 = plot(1:20,100*d1.success12/d1.trials,'x-', ...
          1:20,100*d2.success12/d2.trials,'+-', ...
          1:20,100*d3.success12/d3.trials,'-');

h2 = plot(1:20,100*d1.success11/d1.trials,'x--', ...
          1:20,100*d2.success11/d2.trials,'+--', ...
          1:20,100*d3.success11/d3.trials,'--');
hold off; box on;

% Match colour of lines
for i=1:length(h1)
   set(h2(i),'Color',get(h1(i),'Color'));
end

% Set further figure options
set(gca,'Fontsize',16);
set([h1,h2],'Linewidth',2,'Markersize',7);
legend('r = 2','r = 3','r = 5');
xlabel('s');
ylabel('Recovery rate (%)');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(prefix,'FigBreakdownL12.pdf');
end

