function FigApproachCx_10(exportFlag)
% FIGAPPROACHCX_10   Plots unique orthant count versus iteration
%
%    FIGAPPROACHCX_10(EXPORTFLAG) generates three 10-by-r matrices X, with
%    r = 10,12,15. Based on each X it generates ten million weight vectors w
%    and determines at which iterations a new sign pattern sign(Xw),
%    excluding negation, is encountered. The number of unique patterns is
%    plotted against the number of iterations for all matrices.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get filename prefix
prefix = mfilepath(mfilename('fullpath'));

randn('state',0);
n = 10000000; % Ten million

% Matrix size 10x10
X = randn(10,10);
filename = sprintf('%sFigApproachC10_10.mat',prefix);
if ~exist(filename)
   [idx10,count10] = SampleCdnBasicPairs(X,n);
   save(filename,'idx10','count10');
else
   load(filename);
end

% Matrix size 10x12
X = randn(10,12);
filename = sprintf('%sFigApproachC12_10.mat',prefix);
if ~exist(filename)
   [idx12,count12] = SampleCdnBasicPairs(X,n);
   save(filename,'idx12','count12');
else
   load(filename);
end

% Matrix size 10x15
X = randn(10,15);
filename = sprintf('%sFigApproachC15_10.mat',prefix);
if ~exist(filename)
   [idx15,count15] = SampleCdnBasicPairs(X,n);
   save(filename,'idx15','count15');
else
   load(filename);
end

% Matrix size 10x20, not used in plot
X = randn(10,20);
filename = sprintf('%sFigApproachC20_10.mat',prefix);
if ~exist(filename)
   [idx20,count20] = SampleCdnBasicPairs(X,n);
   save(filename,'idx20','count20');
else
   load(filename);
end

% Plot results
figure(1); clf; gca; hold on;
idxExtended10 = [idx10,n]; countExtended10 = [1:length(idx10),length(idx10)];
idxExtended12 = [idx12,n]; countExtended12 = [1:length(idx12),length(idx12)];
idxExtended15 = [idx15,n]; countExtended15 = [1:length(idx15),length(idx15)];
h = plot(idxExtended10, countExtended10, ...
         idxExtended12, countExtended12, ...
         idxExtended15, countExtended15);
set(gca,'Fontsize',16,'XScale','log');
set(h,'LineWidth',2); xlim([0,n]); ylim([0,550]);

% Add markers to first and second plot
idx = getPlotIndex(log10(idxExtended10),30);
h10 = plot(idxExtended10(idx),countExtended10(idx),'.');
set(h10,'Linewidth',2,'Color',get(h(1),'Color'),'Marker','x','MarkerSize',7);
idx = getPlotIndex(log10(idxExtended12),30);
h12 = plot(idxExtended12(idx),countExtended12(idx),'.');
set(h12,'Linewidth',2,'Color',get(h(2),'Color'),'Marker','+','MarkerSize',7);

% Add dummy lines for legend
hDummy = plot([1,1,1;10,10,10],[-1,-1,-1;-1,-1,-1],'-');
set(hDummy(1),'Linewidth',2,'Color',get(h(1),'Color'),'Marker','x','MarkerSize',7);
set(hDummy(2),'Linewidth',2,'Color',get(h(2),'Color'),'Marker','+','MarkerSize',7);
set(hDummy(3),'Linewidth',2,'Color',get(h(3),'Color'));

hold off; box on;
legend(hDummy,'r = 10','r = 12','r = 15','Location','SouthEast');
xlabel('Iterations'); ylabel('Unique sign patterns');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(prefix,'FigApproachCx_10.pdf');
end

