function FigFiniteCdnPairs(exportFlag)
% FIGFINITECDNPAIRS   Plot range of orthants reached after fixed # of trials
%
%    FIGFINITECDNPAIRS(EXPORTFLAG) plots the minimum, median, and maximum
%    number of unique orthant pairs reached after a fixed number of trials,
%    each with a randomly drawn weight vector w. The theoretically maximum
%    number of orthants is plotted as a reference. When the EXPORTFLAG
%    parameters is set the plot will be exported to a PDF file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get statistics
n = 10;

% Get statistics about number of unique orthants visited after a fixed number
% of trials
cMin = zeros(20,4); cMed = zeros(20,4); cMax = zeros(20,4); 
for d = 1:20
   c = FiniteCdnPairs(d,n);
   for i=1:4
      cMin(d,i) = min(c(:,i));
      cMed(d,i) = median(c(:,i));
      cMax(d,i) = max(c(:,i));
   end
end

% Compute maximum number of unique orthants Cdn
c = zeros(1,20);
for i=1:20
   c(i) = Cdn(i,10);
end

% Plot figure
figure(1); clf; gca; hold on;

h1 = plot(1:20,cMin(:,3),'b--', ...
          1:20,cMed(:,3),'+b-', ...
          1:20,cMax(:,3),'b--');

h2 = plot(1:20,cMin(:,4),'g--', ...
          1:20,cMed(:,4),'xg-', ...
          1:20,cMax(:,4),'g--');

h3 = plot(1:20,c/2,'r-');
hold off; box on;

set(gca,'FontSize',16);
set([h1;h2;h3],'Linewidth',2);
set(h2,'Color',[0 0.9 0]);
hlabel = xlabel('r');
hlabel = [hlabel ylabel('Unique orthant pairs')];
set(hlabel,'Fontsize',22);
legend([h1(2),h2(2),h3],'Trials = 1,000','Trials = 10,000','Trials = Inf','Location','SouthEast');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(mfilepath(mfilename('fullpath')), 'FigFiniteCdnPairs.pdf');
end

