function [idx,count] = SampleCdnBasicPairs(X,trials)
% SAMPLECDNBASICPAIRS   Record unique orthants and trial of first appearance
%
%    [IDX,COUNT] = SAMPLECDNBASICPAIRS(X,TRIALS) generates up to TRIALS weight
%    vectors w to multiply X by. For each sign pattern sign(Xw) we check if
%    it was already encountered (including complete negation of the signs).
%    If the sign pattern is new, we append the trial number to IDX. In any case
%    we increment the COUNT of the pattern, which records the number of times
%    the pattern, or its negation, is observed.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

[n,d]  = size(X);
count  = zeros(1,power(2,n-1));
idx    = zeros(1,power(2,n-1));
binary = power(2,0:n-1);

for j=1:trials
   w = randn(d,1);
   z = (X*w >= 0); if (z(end) == 1), z = 1-z; end;
   i = round(binary*z) + 1;
   count(i) = count(i)+1;

   if idx(i) == 0
      idx(i)   = j;
   end
end

count = count(idx ~= 0);
idx   = idx(idx ~= 0);
[idx,order] = sort(idx,'ascend');
count = count(order);


