function c = SampleCdnPairs(d,n,experiments)
% SAMPLECDNPAIRS   Generates orthant counts after fixed numbers of iterations
%
%    C = SAMPLECDNPAIRS(D,N,EXPERIMENTS) generates a set of EXPERIMENTS random
%    N-by-D matrices X and determines the number of unique sign-patterns were
%    found after multiplying X by up to 10,000 weight vectors. The output C
%    contains the number of orthants found after 10^i, i=1, 2, 3, 4 trials, for
%    each of the experiments.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

codes = int64(zeros(10000,1)); % Maximum 10,000 trials

c = zeros(experiments,4); % 10, 100, 1,000, 10,000 samples
v = power(2,0:n-1);

for i=1:experiments
   X = randn(n,d);

   for j=1:length(codes)
      w = randn(d,1);
      y = (X*w <= 0);

      if y(end) < 0.5
         codes(j) = int64(v*y);
      else
         codes(j) = int64(v*(1-y));
      end
   end

   c(i,1) = length(unique(codes(1:10)));
   c(i,2) = length(unique(codes(1:100)));
   c(i,3) = length(unique(codes(1:1000)));
   c(i,4) = length(unique(codes(1:10000)));
end

