function [A, state] = GenerateMatrixA(m,n)
% GENERATEMATIXA   Generates a standard m-by-n matrix with random entries
%
%    [A,STATE] = GENERATEMATRIXA(M,N)  generates an M-by-N matrix with entries
%    independently sampled from the normal distribution. STATE gives the state
%    of the pseudo-random number generator after generating the matrix. The
%    script restores the original state of the random number generator.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Choose filename
filename = sprintf('%sMatrixA_%d_%d.mat',mfilepath(mfilename('fullpath')),m,n);

if ~exist(filename)
   stateOld = randn('state');
   randn('state',0);
   A = randn(m,n);
   state = randn('state');
   randn('state',stateOld);
   save(filename,'A','state');
else
   load(filename);
end

