function FigReMBoBound(exportFlag)
% FIGREMBOBOUND   Generates ideal performance curves for ReMBo
% 
%    FIGREMBOBOUND(EXPORTFLAG)  generates ideal recovery curves for ReMBo-L1
%    based on three problems with different support size. When the EXPORTFLAG
%    parameters is set the plot will be exported to a PDF file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

figure(1); clf; gca; hold on;

sValues = [8,9,10];
iValues = [4,0,2];
cValues = [0.75  0      0
           0     0.75   0
           0     0      1.00];
markers = {'none','x','+'};

for i=1:length(sValues)
   s   = sValues(i);
   idx = iValues(i);
   r   = 20;

   [A,q,faces] = PresolvedSupportProblem(s,idx);

   remboT = zeros(1,r);
   for k=1:r
      remboT(k) = SuccessRateReMBoTheory(sum(faces),length(faces),Cdn(k,s)/2);
   end

   h(i) = plot(1:r,100*remboT,'r-');

   set(h(i),'LineWidth',2,'Color',cValues(:,i)');
   set(h(i),'Marker',markers{i},'Markersize',7);
end

hold off; box on; ylim([0,102]);
set(gca,'Fontsize',16);
xlabel('r'); ylabel('Recovery rate (%)');
legend(h,'s = 8','s = 9','s = 10','Location','SouthEast');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(mfilepath(mfilename('fullpath')), 'FigReMBoBound.pdf');
end

