function [success,p] = ReMBo_Presolved(r,idx,instances,trials,k)
% REMBO_PRESOLVED   Compute empirical performance of ReMBo
%
%   [SUCCESS,P] = REMBO_PRESOLVED(R,IDX,INSTANCES,TRIALS,K) computes the
%   empirical recovery rate of ReMBo for K measurement vectors, averaged over
%   a number of INSTANCES and with each instance allowing a maximum of TRIALS
%   different weights. The L1 subproblems are solved by using recovery
%   information for all sign patterns on the support of boosted problem
%   (R,IDX). The problem is indexed by R, the row sparsity, and the support
%   index (integer scalar).

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Get matrix, support and map of surviving faces
[A,p,faces] = PresolvedSupportProblem(r,idx);

% Initialize success matrix, binary multiplication coefficients
success  = zeros(1,k);
binary   = power(2,0:r-1);

% Initialize random number generator
randn('state',0)

for i=1:instances
   disp(i);
   for j=1:k
      X = randn(r,j);

      for h=1:trials
         w = randn(j,1);
         xSupport = 1*(X*w>=0); % Sign pattern of support
         xBinary  = binary * xSupport;

         if faces(xBinary+1) ~= 0
            success(j) = success(j) + 1;
            break;
         end
      end
   end
end

% Also return actual probability
p = sum(faces) / power(2,r);

