function [x,info] = cvx_bp(A,b);
% CVX_BP   Solve the basis pursuit problem using CVX
%
%    [X,INFO] = CVX_BP(A,B) solves
%
%          Minimize ||x||_1 subject to Ax = b
%
%    The INFO output structure has the following fields
%       .time_solve   -   Runtime
%       .time_prepare -   Always zero

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

[m,n] = size(A);
info  = struct();

% Start timer
try t0 = toc; catch, tic; t0 = toc; end;

cvx_begin
   variable x(n);
   minimize norm(x,1);
   subject to
      A*x == b;
cvx_end

% Stop timer
info.time_solve = toc - t0;
info.time_prepare = 0;
