function [X,info] = cvx_l11(A,B);
% CVX_L11   Solve the L11 multiple measurement vector problem using CVX
%
%    [X,INFO] = CVX_L11(A,B) solves
%
%          Minimize ||X||_1,1 subject to AX = B
%
%    The INFO output structure has the following fields
%       .time_solve   -   Runtime
%       .time_prepare -   Always zero

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

[m,n] = size(A);
k     = size(B,2);
info  = struct();

% Start timer
tic;

cvx_begin
   variable X(n,k);
   minimize(sum(norms(X,1,2)));
   subject to
      A*X == B;
cvx_end

% Stop timer
info.time_solve = toc;
info.time_prepare = 0;

