function idx = getPlotIndex(x,n)
% GETPLOTINDEX   Chooses subset of points spaced approximately equal
%
%    IDX = GETPLOTINDEX(X,N) generates N indices IDX in X such that
%    the distance between the points is spaced approximately equal.
%    This function is used to generate markers in plots containing
%    too many points to plot directly with markers.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Create n target values
xMin = min(x);
xMax = max(x);
y = linspace(xMin + (xMax - xMin) / (2*n), ...
             xMax - (xMax - xMin) / (2*n),n);

% Find index of point closest to each y
idx = zeros(1,n);
for i=1:n
   [m,j] = min(abs(x-y(i)));
   idx(i) = j;
end

