function PlotTriangle(p,v,success,shift,labels)
% PLOTTRIANGLE  Plot recovery triangles with location representing weight
%
%    PLOTTRIANGLE(P,V,SUCCESS,SHIFT,LABELS)  plots a triangle with corner
%    coordinates in P, and weight normals V based on an boolean array S
%    indicating success or failure of a given trial. The SHIFT parameter
%    is used to align the background pixel array with the triangle. The
%    LABLEL string cell indicates the label associated with each node.
%    Used by TestTriangle.m, TestTriangle2.m, TestTriangle3.m.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

xd = linspace(0,max(p(1,:)),size(success,2));
yd = linspace(0,max(p(2,:)),size(success,1));

% Draw background (needed for proper axis off);
clf; gca; hold on;

% Fill triangle
pcolor(xd - (xd(2)-xd(1))*shift, yd, success), shading flat;

% Get rid of staircase outside of triangle
h = patch(p(1,[1,3,1]),p(2,[1,3,3]),'b');
set(h,'EdgeColor',[1,1,1],...
      'FaceColor',[1,1,1], ...
      'FaceVertexCData',ones(3,3)); % Needed to stop Matlab from nagging
h = patch(p(1,[2,3,2]),p(2,[2,3,3]),'b');
set(h,'EdgeColor',[1,1,1],...
      'FaceColor',[1,1,1]);

% Draw outline
h = plot(p(1,[1,2,3,1]),p(2,[1,2,3,1]),'k-');
set(h,'linewidth',2)
hold off;

% Set colormap
colormap([0.8 0.8 1.0; 0.0 0.0 0.7]) 

% Set axis limits
set(gca,'XTick',[],'YTick',[]); box off;
set(gca,'XColor',[1,1,1],'YColor',[1,1,1]);

xlim([-0.0,1.0]);
ylim([-0.0,max(yd)]);

% Add text
for i=1:3
   pos = p(:,i) - diag(0.05,0.05) * v(:,i) / norm(v(:,i),inf);
   h = text(pos(1),pos(2),labels{i});
   set(h,'Fontsize',24);
end

